==> haskell-hls-splice-plugin-2.0.0.0-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-splice-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-splice-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-splice-plugin-2.0.0.0-CNmPhVpp57zAYjACr0jHiL
key:                  hls-splice-plugin-2.0.0.0-CNmPhVpp57zAYjACr0jHiL
license:              Apache-2.0
maintainer:
    https://github.com/haskell/haskell-language-server/contributors

author:
    https://github.com/haskell/haskell-language-server/contributors

synopsis:
    HLS Plugin to expand TemplateHaskell Splices and QuasiQuotes

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  d7e33940dfd5f492bc22cc097fc8ae27
exposed:              True
exposed-modules:      Ide.Plugin.Splice Ide.Plugin.Splice.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-splice-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-splice-plugin-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-splice-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-splice-plugin
hs-libraries:         HShls-splice-plugin-2.0.0.0-CNmPhVpp57zAYjACr0jHiL
depends:
    aeson-2.1.2.1-7NKMY9av0haL3nHVKphSJj base-4.17.2.1 containers-0.6.7
    dlist-1.0-I6FB5Nlk17hG16fxQzZSEb
    extra-1.7.16-LRPaj0kKdYhA5DC3OzySjK
    foldl-1.4.17-3P6kdqoRovmCVgbMOc5ZE ghc-9.4.8
    ghc-exactprint-1.6.1-1pC2UooR1UK8f5nfgopCxy
    ghcide-2.0.0.0-DRI4NY9c6PIkGk9WaJTQj
    hls-plugin-api-2.0.0.0-I7YEHyKncWN58S7zoavJND
    hls-refactor-plugin-2.0.0.0-8TO4uZ5Gzc0KtFtiTUzVWr
    lens-5.2.3-4nDp1u1qKC5FV2ww18Mx1 lsp-1.6.0.0-LOrWurGUfcm1ZXl1RcyPxv
    retrie-1.2.3-7gShyMQ4ucmBI3jyuz1Qlz
    syb-0.7.2.4-1AaSJ4gAQqF80sCpMGQHRf text-2.0.2 transformers-0.5.6.2
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    unordered-containers-0.2.20-1zjZuvvQz6A9v2Utwl5wnX

haddock-interfaces:
    /usr/share/doc/haskell-hls-splice-plugin/html/hls-splice-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-splice-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-splice-plugin-2.0.0.0-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-splice-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-splice-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-splice-plugin-2.0.0.0-8opeJfY23yYAe0WnbCOwKI
key:                  hls-splice-plugin-2.0.0.0-8opeJfY23yYAe0WnbCOwKI
license:              Apache-2.0
maintainer:
    https://github.com/haskell/haskell-language-server/contributors

author:
    https://github.com/haskell/haskell-language-server/contributors

synopsis:
    HLS Plugin to expand TemplateHaskell Splices and QuasiQuotes

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  196e2b2b5bbf7cb8172c86e8fa439fd7
exposed:              True
exposed-modules:      Ide.Plugin.Splice Ide.Plugin.Splice.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-splice-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-splice-plugin-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-splice-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-splice-plugin
hs-libraries:         HShls-splice-plugin-2.0.0.0-8opeJfY23yYAe0WnbCOwKI
depends:
    aeson-2.1.2.1-7NKMY9av0haL3nHVKphSJj base-4.17.2.1 containers-0.6.7
    dlist-1.0-I6FB5Nlk17hG16fxQzZSEb
    extra-1.7.16-LRPaj0kKdYhA5DC3OzySjK
    foldl-1.4.17-3P6kdqoRovmCVgbMOc5ZE ghc-9.4.8
    ghc-exactprint-1.6.1-1pC2UooR1UK8f5nfgopCxy
    ghcide-2.0.0.0-1UXOBe0HT3ICfnA7ApAAfD
    hls-plugin-api-2.0.0.0-L5enBKJhMYCCSCAkShlHZC
    hls-refactor-plugin-2.0.0.0-6Hfb8lLOxuoAETsDzaRQX2
    lens-5.2.3-4nDp1u1qKC5FV2ww18Mx1 lsp-1.6.0.0-LOrWurGUfcm1ZXl1RcyPxv
    retrie-1.2.3-7gShyMQ4ucmBI3jyuz1Qlz
    syb-0.7.2.4-1AaSJ4gAQqF80sCpMGQHRf text-2.0.2 transformers-0.5.6.2
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    unordered-containers-0.2.20-1zjZuvvQz6A9v2Utwl5wnX

haddock-interfaces:
    /usr/share/doc/haskell-hls-splice-plugin/html/hls-splice-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-splice-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
